@@ -25,7 +25,7 @@ pub struct SetKeyspace {
 pub struct Prepared {
     pub id: Bytes,
     pub prepared_metadata: PreparedMetadata,
-    result_metadata: ResultMetadata,
+    pub result_metadata: ResultMetadata,
 }
 
 #[derive(Debug)]
@@ -36,11 +36,11 @@ pub struct SchemaChange {
 #[derive(Clone, Debug)]
 pub struct TableSpec {
     pub ks_name: String,
-    table_name: String,
+    pub table_name: String,
 }
 
 #[derive(Debug, Clone)]
-enum ColumnType {
+pub enum ColumnType {
     Ascii,
     Boolean,
     Blob,
@@ -71,7 +71,7 @@ enum ColumnType {
     Varint,
 }
 
-#[derive(Debug, PartialEq)]
+#[derive(Clone, Debug, PartialEq)]
 pub enum CqlValue {
     Ascii(String),
     Boolean(bool),
@@ -297,7 +297,7 @@ impl CqlValue {
 pub struct ColumnSpec {
     pub table_spec: TableSpec,
     pub name: String,
-    typ: ColumnType,
+    pub typ: ColumnType,
 }
 
 #[derive(Debug, Default)]
@@ -326,10 +326,10 @@ impl Row {
     }
 }
 
-#[derive(Debug, Default)]
+#[derive(Debug)]
 pub struct Rows {
     pub metadata: ResultMetadata,
-    rows_count: usize,
+    pub rows_count: usize,
     pub rows: Vec<Row>,
 }
 
