@@ -1,10 +1,11 @@
+use crate::frame::types;
 use bigdecimal::BigDecimal;
 use bytes::BufMut;
 use chrono::prelude::*;
 use chrono::Duration;
 use num_bigint::BigInt;
 use std::borrow::Cow;
-use std::collections::HashMap;
+use std::collections::{BTreeMap, BTreeSet, HashMap, HashSet};
 use std::convert::TryInto;
 use std::net::IpAddr;
 use thiserror::Error;
@@ -56,14 +57,19 @@ pub struct Time(pub Duration);
 pub struct SerializedValues {
     serialized_values: Vec<u8>,
     values_num: i16,
+    contains_names: bool,
 }
 
 #[derive(Debug, Error, Clone, Copy, PartialEq, Eq, PartialOrd, Ord)]
 pub enum SerializeValuesError {
     #[error("Too many values to add, max 32 767 values can be sent in a request")]
     TooManyValues,
+    #[error("Mixing named and not named values is not allowed")]
+    MixingNamedAndNotNamedValues,
     #[error(transparent)]
     ValueTooBig(#[from] ValueTooBig),
+    #[error("Parsing serialized values failed")]
+    ParseError,
 }
 
 pub type SerializedResult<'a> = Result<Cow<'a, SerializedValues>, SerializeValuesError>;
@@ -104,6 +110,7 @@ impl SerializedValues {
         SerializedValues {
             serialized_values: Vec::new(),
             values_num: 0,
+            contains_names: false,
         }
     }
 
@@ -111,14 +118,22 @@ impl SerializedValues {
         SerializedValues {
             serialized_values: Vec::with_capacity(capacity),
             values_num: 0,
+            contains_names: false,
         }
     }
 
+    pub fn has_names(&self) -> bool {
+        self.contains_names
+    }
+
     /// A const empty instance, useful for taking references
     pub const EMPTY: &'static SerializedValues = &SerializedValues::new();
 
     /// Serializes value and appends it to the list
     pub fn add_value(&mut self, val: &impl Value) -> Result<(), SerializeValuesError> {
+        if self.contains_names {
+            return Err(SerializeValuesError::MixingNamedAndNotNamedValues);
+        }
         if self.values_num == i16::max_value() {
             return Err(SerializeValuesError::TooManyValues);
         }
@@ -134,10 +149,38 @@ impl SerializedValues {
         Ok(())
     }
 
+    pub fn add_named_value(
+        &mut self,
+        name: &str,
+        val: &impl Value,
+    ) -> Result<(), SerializeValuesError> {
+        if self.values_num > 0 && !self.contains_names {
+            return Err(SerializeValuesError::MixingNamedAndNotNamedValues);
+        }
+        self.contains_names = true;
+        if self.values_num == i16::max_value() {
+            return Err(SerializeValuesError::TooManyValues);
+        }
+
+        let len_before_serialize: usize = self.serialized_values.len();
+
+        types::write_string(name, &mut self.serialized_values)
+            .map_err(|_| SerializeValuesError::ParseError)?;
+
+        if let Err(e) = val.serialize(&mut self.serialized_values) {
+            self.serialized_values.resize(len_before_serialize, 0);
+            return Err(SerializeValuesError::from(e));
+        }
+
+        self.values_num += 1;
+        Ok(())
+    }
+
     pub fn iter(&self) -> impl Iterator<Item = Option<&[u8]>> {
         SerializedValuesIterator {
             serialized_values: &self.serialized_values,
             next_offset: 0,
+            contains_names: self.contains_names,
         }
     }
 
@@ -159,13 +202,23 @@ impl SerializedValues {
 pub struct SerializedValuesIterator<'a> {
     serialized_values: &'a [u8],
     next_offset: usize,
+    contains_names: bool,
 }
 
 impl<'a> Iterator for SerializedValuesIterator<'a> {
     type Item = Option<&'a [u8]>;
 
     fn next(&mut self) -> Option<Self::Item> {
-        // Read next value's 4 byte size, return it, advance
+        // Read next value's 4 byte size, return it, advance.
+        // In case of named values, skip names
+        if self.contains_names {
+            if self.next_offset + 2 > self.serialized_values.len() {
+                return None;
+            }
+            let mut len_bytes = &self.serialized_values[self.next_offset..(self.next_offset + 2)];
+            let next_name_len: usize = types::read_short_length(&mut len_bytes).ok()?;
+            self.next_offset += 2 + next_name_len;
+        }
 
         if self.next_offset + 4 > self.serialized_values.len() {
             // Reached the end - nothing more to read
@@ -447,27 +500,53 @@ fn serialize_map<K: Value, V: Value>(
     Ok(())
 }
 
+fn serialize_list_or_set<'a, V: 'a + Value>(
+    elements_iter: impl Iterator<Item = &'a V>,
+    element_count: usize,
+    buf: &mut Vec<u8>,
+) -> Result<(), ValueTooBig> {
+    let bytes_num_pos: usize = buf.len();
+    buf.put_i32(0);
+
+    buf.put_i32(element_count.try_into().map_err(|_| ValueTooBig)?);
+    for value in elements_iter {
+        <V as Value>::serialize(value, buf)?;
+    }
+
+    let written_bytes: usize = buf.len() - bytes_num_pos - 4;
+    let written_bytes_i32: i32 = written_bytes.try_into().map_err(|_| ValueTooBig)?;
+    buf[bytes_num_pos..(bytes_num_pos + 4)].copy_from_slice(&written_bytes_i32.to_be_bytes());
+
+    Ok(())
+}
+
+impl<V: Value> Value for HashSet<V> {
+    fn serialize(&self, buf: &mut Vec<u8>) -> Result<(), ValueTooBig> {
+        serialize_list_or_set(self.iter(), self.len(), buf)
+    }
+}
+
 impl<K: Value, V: Value> Value for HashMap<K, V> {
     fn serialize(&self, buf: &mut Vec<u8>) -> Result<(), ValueTooBig> {
         serialize_map(self.iter(), self.len(), buf)
     }
 }
 
+impl<V: Value> Value for BTreeSet<V> {
+    fn serialize(&self, buf: &mut Vec<u8>) -> Result<(), ValueTooBig> {
+        serialize_list_or_set(self.iter(), self.len(), buf)
+    }
+}
+
+impl<K: Value, V: Value> Value for BTreeMap<K, V> {
+    fn serialize(&self, buf: &mut Vec<u8>) -> Result<(), ValueTooBig> {
+        serialize_map(self.iter(), self.len(), buf)
+    }
+}
+
 impl<T: Value> Value for Vec<T> {
     fn serialize(&self, buf: &mut Vec<u8>) -> Result<(), ValueTooBig> {
-        let bytes_num_pos: usize = buf.len();
-        buf.put_i32(0);
-
-        buf.put_i32(self.len().try_into().map_err(|_| ValueTooBig)?);
-        for value in self {
-            <T as Value>::serialize(value, buf)?;
-        }
-
-        let written_bytes: usize = buf.len() - bytes_num_pos - 4;
-        let written_bytes_i32: i32 = written_bytes.try_into().map_err(|_| ValueTooBig)?;
-        buf[bytes_num_pos..(bytes_num_pos + 4)].copy_from_slice(&written_bytes_i32.to_be_bytes());
-
-        Ok(())
+        serialize_list_or_set(self.iter(), self.len(), buf)
     }
 }
 
@@ -617,6 +696,27 @@ impl<T: Value> ValueList for Vec<T> {
     }
 }
 
+// Implement ValueList for maps, which serializes named values
+macro_rules! impl_value_list_for_map {
+    ($map_type:ident, $key_type:ty) => {
+        impl<T: Value> ValueList for $map_type<$key_type, T> {
+            fn serialized(&self) -> SerializedResult<'_> {
+                let mut result = SerializedValues::with_capacity(self.len());
+                for (key, val) in self {
+                    result.add_named_value(key, val)?;
+                }
+
+                Ok(Cow::Owned(result))
+            }
+        }
+    };
+}
+
+impl_value_list_for_map!(HashMap, String);
+impl_value_list_for_map!(HashMap, &str);
+impl_value_list_for_map!(BTreeMap, String);
+impl_value_list_for_map!(BTreeMap, &str);
+
 // Implement ValueList for tuples of Values of size up to 16
 
 // Here is an example implemetation for (T0, )
