@@ -1,8 +1,9 @@
 //! This module contains various erros which can be returned by [`Session`](crate::Session)
 
 use crate::frame::frame_errors::{FrameError, ParseError};
+use crate::frame::types::LegacyConsistency;
 use crate::frame::value::SerializeValuesError;
-use crate::statement::Consistency;
+use bytes::Bytes;
 use std::io::ErrorKind;
 use std::sync::Arc;
 use thiserror::Error;
@@ -33,10 +34,16 @@ pub enum QueryError {
     /// Timeout error has occured, function didn't complete in time.
     #[error("Timeout Error")]
     TimeoutError,
+
+    #[error("Too many orphaned stream ids: {0}")]
+    TooManyOrphanedStreamIds(u16),
+
+    #[error("Unable to allocate stream id")]
+    UnableToAllocStreamId,
 }
 
 /// An error sent from the database in response to a query
-/// as described in the [specification](https://github.com/apache/cassandra/blob/5ed5e84613ef0e9664a774493db7d2604e3596e0/doc/native_protocol_v4.spec#L1029)  
+/// as described in the [specification](https://github.com/apache/cassandra/blob/5ed5e84613ef0e9664a774493db7d2604e3596e0/doc/native_protocol_v4.spec#L1029)\
 #[derive(Error, Debug, Clone, PartialEq, Eq)]
 pub enum DbError {
     /// The submitted query has a syntax error
@@ -92,7 +99,7 @@ pub enum DbError {
     )]
     Unavailable {
         /// Consistency level of the query
-        consistency: Consistency,
+        consistency: LegacyConsistency,
         /// Number of nodes required to be alive to satisfy required consistency level
         required: i32,
         /// Found number of active nodes
@@ -116,7 +123,7 @@ pub enum DbError {
             (consistency: {consistency}, received: {received}, required: {required}, data_present: {data_present})")]
     ReadTimeout {
         /// Consistency level of the query
-        consistency: Consistency,
+        consistency: LegacyConsistency,
         /// Number of nodes that responded to the read request
         received: i32,
         /// Number of nodes required to respond to satisfy required consistency level
@@ -130,7 +137,7 @@ pub enum DbError {
             (consistency: {consistency}, received: {received}, required: {required}, write_type: {write_type})")]
     WriteTimeout {
         /// Consistency level of the query
-        consistency: Consistency,
+        consistency: LegacyConsistency,
         /// Number of nodes that responded to the write request
         received: i32,
         /// Number of nodes required to respond to satisfy required consistency level
@@ -147,7 +154,7 @@ pub enum DbError {
     )]
     ReadFailure {
         /// Consistency level of the query
-        consistency: Consistency,
+        consistency: LegacyConsistency,
         /// Number of nodes that responded to the read request
         received: i32,
         /// Number of nodes required to respond to satisfy required consistency level
@@ -166,7 +173,7 @@ pub enum DbError {
     )]
     WriteFailure {
         /// Consistency level of the query
-        consistency: Consistency,
+        consistency: LegacyConsistency,
         /// Number of ndoes that responded to the read request
         received: i32,
         /// Number of nodes required to respond to satisfy required consistency level
@@ -181,7 +188,10 @@ pub enum DbError {
     #[error(
         "Tried to execute a prepared statement that is not prepared. Driver shoud prepare it again"
     )]
-    Unprepared,
+    Unprepared {
+        /// Statement id of the requested prepared query
+        statement_id: Bytes,
+    },
 
     /// Internal server error. This indicates a server-side bug
     #[error("Internal server error. This indicates a server-side bug")]
@@ -276,6 +286,12 @@ pub enum NewSessionError {
     /// Timeout error has occured, couldn't connect to node in time.
     #[error("Timeout Error")]
     TimeoutError,
+
+    #[error("Too many orphaned stream ids: {0}")]
+    TooManyOrphanedStreamIds(u16),
+
+    #[error("Unable to allocate stream id")]
+    UnableToAllocStreamId,
 }
 
 /// Invalid keyspace name given to `Session::use_keyspace()`
@@ -339,6 +355,10 @@ impl From<QueryError> for NewSessionError {
             QueryError::ProtocolError(m) => NewSessionError::ProtocolError(m),
             QueryError::InvalidMessage(m) => NewSessionError::InvalidMessage(m),
             QueryError::TimeoutError => NewSessionError::TimeoutError,
+            QueryError::TooManyOrphanedStreamIds(ids) => {
+                NewSessionError::TooManyOrphanedStreamIds(ids)
+            }
+            QueryError::UnableToAllocStreamId => NewSessionError::UnableToAllocStreamId,
         }
     }
 }
@@ -385,6 +405,7 @@ impl From<&str> for WriteType {
 #[cfg(test)]
 mod tests {
     use super::{DbError, QueryError, WriteType};
+    use crate::frame::types::LegacyConsistency;
     use crate::statement::Consistency;
 
     #[test]
@@ -416,7 +437,7 @@ mod tests {
     fn dberror_full_info() {
         // Test that DbError::Unavailable is displayed correctly
         let db_error = DbError::Unavailable {
-            consistency: Consistency::Three,
+            consistency: LegacyConsistency::Regular(Consistency::Three),
             required: 3,
             alive: 2,
         };
