@@ -1,6 +1,6 @@
-//! Load balancing configurations  
-//! `Session` can use any load balancing policy which implements the `LoadBalancingPolicy` trait  
-//! Policies which implement the `ChildLoadBalancingPolicy` can be wrapped in some other policies  
+//! Load balancing configurations\
+//! `Session` can use any load balancing policy which implements the `LoadBalancingPolicy` trait\
+//! Policies which implement the `ChildLoadBalancingPolicy` can be wrapped in some other policies\
 //! See [the book](https://cvybhu.github.io/scyllabook/load-balancing/load-balancing.html) for more information
 
 use super::{cluster::ClusterData, node::Node};
@@ -17,6 +17,7 @@ pub use round_robin::RoundRobinPolicy;
 pub use token_aware::TokenAwarePolicy;
 
 /// Represents info about statement that can be used by load balancing policies.
+#[derive(Default)]
 pub struct Statement<'a> {
     pub token: Option<Token>,
     pub keyspace: Option<&'a str>,
@@ -71,21 +72,12 @@ fn slice_rotated_left<'a, T>(slice: &'a [T], mid: usize) -> impl Iterator<Item =
     begin.iter().chain(end.iter())
 }
 
-impl Default for Statement<'_> {
-    fn default() -> Self {
-        Statement {
-            token: None,
-            keyspace: None,
-        }
-    }
-}
-
 #[cfg(test)]
 mod tests {
     use super::*;
 
+    use crate::transport::topology::Metadata;
     use crate::transport::topology::Peer;
-    use crate::transport::topology::TopologyInfo;
     use std::collections::HashMap;
     use std::net::SocketAddr;
 
@@ -134,7 +126,7 @@ mod tests {
             })
             .collect::<Vec<_>>();
 
-        let info = TopologyInfo {
+        let info = Metadata {
             peers,
             keyspaces: HashMap::new(),
         };
