@@ -1,20 +1,20 @@
-//! Query retries configurations  
+//! Query retries configurations\
 //! To decide when to retry a query the `Session` can use any object which implements
 //! the `RetryPolicy` trait
 
-use crate::statement::Consistency;
+use crate::frame::types::LegacyConsistency;
 use crate::transport::errors::{DbError, QueryError, WriteType};
 
 /// Information about a failed query
 pub struct QueryInfo<'a> {
     /// The error with which the query failed
     pub error: &'a QueryError,
-    /// A query is idempotent if it can be applied multiple times without changing the result of the initial application  
-    /// If set to `true` we can be sure that it is idempotent  
+    /// A query is idempotent if it can be applied multiple times without changing the result of the initial application\
+    /// If set to `true` we can be sure that it is idempotent\
     /// If set to `false` it is unknown whether it is idempotent
     pub is_idempotent: bool,
     /// Consistency with which the query failed
-    pub consistency: Consistency,
+    pub consistency: LegacyConsistency,
 }
 
 #[derive(Debug, PartialEq, Eq)]
@@ -83,7 +83,7 @@ impl RetrySession for FallthroughRetrySession {
     fn reset(&mut self) {}
 }
 
-/// Default retry policy - retries when there is a high chance that a retry might help.  
+/// Default retry policy - retries when there is a high chance that a retry might help.\
 /// Behaviour based on [DataStax Java Driver](https://docs.datastax.com/en/developer/java-driver/4.10/manual/core/retries/)
 pub struct DefaultRetryPolicy;
 
@@ -211,8 +211,10 @@ impl RetrySession for DefaultRetrySession {
 #[cfg(test)]
 mod tests {
     use super::{DefaultRetryPolicy, QueryInfo, RetryDecision, RetryPolicy};
+    use crate::frame::types::LegacyConsistency;
     use crate::statement::Consistency;
     use crate::transport::errors::{BadQuery, DbError, QueryError, WriteType};
+    use bytes::Bytes;
     use std::io::ErrorKind;
     use std::sync::Arc;
 
@@ -220,7 +222,7 @@ mod tests {
         QueryInfo {
             error,
             is_idempotent,
-            consistency: Consistency::One,
+            consistency: LegacyConsistency::Regular(Consistency::One),
         }
     }
 
@@ -257,20 +259,22 @@ mod tests {
             DbError::Unauthorized,
             DbError::ConfigError,
             DbError::ReadFailure {
-                consistency: Consistency::Two,
+                consistency: LegacyConsistency::Regular(Consistency::Two),
                 received: 2,
                 required: 1,
                 numfailures: 1,
                 data_present: false,
             },
             DbError::WriteFailure {
-                consistency: Consistency::Two,
+                consistency: LegacyConsistency::Regular(Consistency::Two),
                 received: 1,
                 required: 2,
                 numfailures: 1,
                 write_type: WriteType::BatchLog,
             },
-            DbError::Unprepared,
+            DbError::Unprepared {
+                statement_id: Bytes::from_static(b"deadbeef"),
+            },
             DbError::ProtocolError,
             DbError::Other(0x124816),
         ];
@@ -335,7 +339,7 @@ mod tests {
     fn default_unavailable() {
         let error = QueryError::DbError(
             DbError::Unavailable {
-                consistency: Consistency::Two,
+                consistency: LegacyConsistency::Regular(Consistency::Two),
                 required: 2,
                 alive: 1,
             },
@@ -369,7 +373,7 @@ mod tests {
         // Enough responses and data_present == true
         let enough_responses_with_data = QueryError::DbError(
             DbError::ReadTimeout {
-                consistency: Consistency::Two,
+                consistency: LegacyConsistency::Regular(Consistency::Two),
                 received: 2,
                 required: 2,
                 data_present: true,
@@ -402,7 +406,7 @@ mod tests {
         // Enough responses but data_present == false
         let enough_responses_no_data = QueryError::DbError(
             DbError::ReadTimeout {
-                consistency: Consistency::Two,
+                consistency: LegacyConsistency::Regular(Consistency::Two),
                 received: 2,
                 required: 2,
                 data_present: false,
@@ -427,7 +431,7 @@ mod tests {
         // Not enough responses, data_present == true
         let not_enough_responses_with_data = QueryError::DbError(
             DbError::ReadTimeout {
-                consistency: Consistency::Two,
+                consistency: LegacyConsistency::Regular(Consistency::Two),
                 received: 1,
                 required: 2,
                 data_present: true,
@@ -456,7 +460,7 @@ mod tests {
         // WriteType == BatchLog
         let good_write_type = QueryError::DbError(
             DbError::WriteTimeout {
-                consistency: Consistency::Two,
+                consistency: LegacyConsistency::Regular(Consistency::Two),
                 received: 1,
                 required: 2,
                 write_type: WriteType::BatchLog,
@@ -485,7 +489,7 @@ mod tests {
         // WriteType != BatchLog
         let bad_write_type = QueryError::DbError(
             DbError::WriteTimeout {
-                consistency: Consistency::Two,
+                consistency: LegacyConsistency::Regular(Consistency::Two),
                 received: 4,
                 required: 2,
                 write_type: WriteType::Simple,
